#!/usr/bin/R
# Title:
# Version: 
# Author: Frédéric CHEVALIER
# Created in:
# Modified in:



#------#
# Aims #
#------#





#-----------------#
# Library loading #
#-----------------#




#-----------#
# Variables #
#-----------#

# Remove all variables from the memory
rm(list = ls())

# Data file
file <- ""

data <- read.csv(file, header=T, sep=";")

# Object containing the name of the data file
name <- strsplit(file,".csv")



#-----------------#
# Data Processing #
#-----------------#



# Result export in folder
if (file.exists("Results/") == FALSE) {dir.create("Results")}
write.table(x, file=paste("Résultats/x",file, sep=""), col.names = NA, row.names = TRUE, sep=";") # x = object to save



#--------------------#
# Graphical commands #
#--------------------#




#------#
# Plot #
#------#





# Create the graph folder if it do not already exist
if (file.exists("Graphs/") == FALSE) {dir.create("Graphs")}

postscript(file=paste("Graphs/", name, ".ps", sep="")

# Draw graph here

dev.off()


## Save the graph in png format
#savePlot(paste("Graphs/",name,".png", sep=""))

